@@ -190,17 +190,16 @@ addArgument <- function(functions, exclude = character()) {
 #'
 #' @noRd
 #'
-addOtherColumns <- function(table, tableName) {
-
+addOtherColumns <- function(table, tableName, version = "5.3") {
   colToAdd <- base::setdiff(
-    omopgenerics::omopColumns(tableName), colnames(table))
+    omopgenerics::omopColumns(tableName, version = version), colnames(table)
+  )
 
   for (col in colToAdd) {
     table[[col]] <- NA
   }
 
   return(table)
-
 }
 
 #' Format columns of omop table to correct format
@@ -221,7 +220,6 @@ correctCdmFormat <- function(table, tableName) {
 
       if (colType == "date") {
         table[[colName]] <- as.Date(table[[colName]], "%d/%m/%Y")
-
       }
 
       if (colType == "datetime") {
@@ -236,14 +234,10 @@ correctCdmFormat <- function(table, tableName) {
       if (grepl("varchar", colType)) {
         table[[colName]] <- as.character(table[[colName]])
       }
-
     }
-
   }
 
   return(table)
-
-
 }
 #' get column start date
 #'
@@ -256,3 +250,21 @@ startDateColumn <- function(tableName) {
     return("cohort_start_date")
   }
 }
+
+
+
+#' change column name
+#'
+#' @noRd
+#'
+changeColumnsName <- function(table, tableName, version = "5.3") {
+  colToAdd <- base::setdiff(
+    omopgenerics::omopColumns(tableName, version = version), colnames(table)
+  )
+
+  for (col in colToAdd) {
+    table[[col]] <- NA
+  }
+
+  return(table)
+}
